@@ -1,7 +1,7 @@
 /* tests/mpria_test.h -- C header file */
 /*
  * MPRIA - GNU Multi-Precision Rational Interval Arithmetic Library
- * Copyright (C) 2009-2014  Jerome Benoit <jgmbenoit@rezozer.net>
+ * Copyright (C) 2009-2016  Jerome Benoit <jgmbenoit@rezozer.net>
  *
  * This file is part of the GNU MPRIA Library.
  *
@@ -30,6 +30,15 @@
 #define MPRIA_FAILURE -1
 #endif
 
+/* borrow from GSL */
+#ifdef NAN
+# define MPRIA_NAN NAN
+#elif defined(INFINITY)
+# define MPRIA_NAN (INFINITY/INFINITY)
+#else
+# define MPRIA_NAN (0.0/0.0)
+#endif
+
 #undef __BEGIN_DECLS
 #undef __END_DECLS
 #ifdef __cplusplus
